@@ -35,7 +35,6 @@ def after_experiment_control(
             url, payload = result
             extension = get_reliably_extension_from_journal(state)
             extension["execution_url"] = url
-            extension["execution_info"] = payload
     except Exception as ex:
         logger.debug(
             f"An error occurred: {ex}, while running the after-experiment "
@@ -71,7 +70,7 @@ def complete_run(
 
 def get_reliably_extension_from_journal(journal: Journal) -> Dict[str, Any]:
     experiment = journal.get("experiment")
-    extensions = experiment.get("extensions", [])
+    extensions = experiment.setdefault("extensions", [])
     for extension in extensions:
         if extension["name"] == "reliably":
             return cast(Dict[str, Any], extension)
